package de.ozgcloud.archive.common.xta;

import java.io.IOException;

import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.parsers.ParserConfigurationException;

import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.Lazy;

import com.fasterxml.jackson.databind.ObjectMapper;

import de.ozgcloud.archive.common.xta.XtaProperties.XtaClientKeyStore;
import de.ozgcloud.common.errorhandling.TechnicalException;
import de.ozgcloud.xta.client.XtaClient;
import de.ozgcloud.xta.client.config.XtaClientConfig;
import de.ozgcloud.xta.client.config.XtaClientConfig.KeyStore;
import de.ozgcloud.xta.client.exception.XtaClientInitializationException;

@Configuration
class XtaConfiguration {

	@Bean
	@ConditionalOnProperty(prefix = XtaProperties.XTA_PROPERTIES_PREFIX, name = "enabled")
	XtaClient xtaClient(XtaProperties xtaProperties) {
		try {
			return XtaClient.from(buildXtaClientConfig(xtaProperties));
		} catch (XtaClientInitializationException e) {
			throw new TechnicalException("Error on initializing Xta client.", e);
		}
	}

	XtaClientConfig buildXtaClientConfig(XtaProperties xtaProperties) {
		return XtaClientConfig.builder()
				.sendServiceUrl(xtaProperties.getSendServiceUrl())
				.managementServiceUrl(xtaProperties.getManagementServiceUrl())
				.msgBoxServiceUrl(xtaProperties.getMsgBoxServiceUrl())
				.clientCertKeystore(buildKeystore(xtaProperties.getKeyStore()))
				.trustStore(buildKeystore(xtaProperties.getTrustStore()))
				.maxListItems(xtaProperties.getMaxLoadedMessages())
				.clientIdentifiers(xtaProperties.getClientIdentifiers())
				.build();
	}

	private KeyStore buildKeystore(XtaClientKeyStore clientCert) {
		try {
			return XtaClientConfig.KeyStore.builder()
					.content(clientCert.getFile().getContentAsByteArray())
					.type(clientCert.getType())
					.password(clientCert.getPassword())
					.build();
		} catch (IOException e) {
			throw new TechnicalException("Error on reading Xta client certificate.", e);
		}
	}

	@Bean
	@Lazy
	ObjectMapper objectMapper() {
		return new ObjectMapper();
	}

	@Bean
	DocumentBuilder documentBuilder() throws ParserConfigurationException {
		return DocumentBuilderFactory.newDefaultInstance().newDocumentBuilder();
	}
}
