package de.ozgcloud.archive.common.xta;

import java.io.IOException;

import javax.xml.parsers.DocumentBuilder;

import org.springframework.stereotype.Component;
import org.w3c.dom.Document;
import org.xml.sax.SAXException;

import de.ozgcloud.xta.client.model.XtaFile;
import lombok.RequiredArgsConstructor;
import lombok.extern.log4j.Log4j2;

@Log4j2
@RequiredArgsConstructor
@Component
public class XtaFileParser {

	private final DocumentBuilder documentBuilder;

	public boolean isType(XtaFile file, XtaFileType type) {
		try {
			var doc = parse(file);
			return type.getTypeStr().equals(getRootTagName(doc));
		} catch (Exception e) {
			LOG.warn("Error parsing xta file.", e);
			return false;
		}
	}

	Document parse(XtaFile file) throws SAXException, IOException {
		var document = documentBuilder.parse(file.content().getDataSource().getInputStream());
		document.getDocumentElement().normalize();
		return document;
	}

	private String getRootTagName(Document doc) {
		return doc.getDocumentElement().getTagName();
	}
}