/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.archive.vorgang;

import static java.util.Optional.*;

import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Component;

import de.xoev.xdomea.AllgemeinerNameType;
import de.xoev.xdomea.NameNatuerlichePersonType;

@Component
class NameNatuerlichePersonTypeCreator {

	public NameNatuerlichePersonType create(Antragsteller antragsteller) {
		var nameNatuerlichPerson = new NameNatuerlichePersonType();
		nameNatuerlichPerson.setAnrede(ofNullable(antragsteller).map(Antragsteller::getAnrede).orElse(StringUtils.EMPTY));
		nameNatuerlichPerson.setVorname(
				createAllgemeinerNameType(ofNullable(antragsteller).map(Antragsteller::getVorname).orElse(StringUtils.EMPTY)));
		nameNatuerlichPerson.setFamilienname(
				createAllgemeinerNameType(ofNullable(antragsteller).map(Antragsteller::getNachname).orElse(StringUtils.EMPTY)));
		return nameNatuerlichPerson;
	}

	private AllgemeinerNameType createAllgemeinerNameType(String name) {
		var allgemeinerName = new AllgemeinerNameType();
		allgemeinerName.setName(name);
		return allgemeinerName;
	}
}
