/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.archive.vorgang;

import java.util.UUID;

import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Component;

import de.ozgcloud.archive.export.XdomeaMedienart;
import de.xoev.xdomea.AllgemeineMetadatenType;
import de.xoev.xdomea.IdentifikationObjektType;
import de.xoev.xdomea.MediumCodeType;
import de.xoev.xdomea.VorgangType;
import lombok.RequiredArgsConstructor;

@RequiredArgsConstructor
@Component
class VorgangTypeCreator {

	static final Long NUMMER_IM_UEBERGEORDNETEN_CONTAINER = 1L;

	private final AnwendungsspezifischeErweiterungTypeCreator anwendungsspezifischeErweiterungTypeCreator;
	private final AnwendungsspezifischeErweiterungXMLTypeCreator anwendungsspezifischeErweiterungXMLTypeCreator;
	private final KontaktTypeCreator kontaktTypeCreator;

	public VorgangType create(VorgangWithEingang vorgangWithEingang) {
		var vorgang = new VorgangType();
		vorgang.setAnwendungsspezifischeErweiterung(anwendungsspezifischeErweiterungTypeCreator.create(vorgangWithEingang));
		vorgang.setAnwendungsspezifischeErweiterungXML(anwendungsspezifischeErweiterungXMLTypeCreator.create(vorgangWithEingang));
		vorgang.setIdentifikation(createIdentifikation());
		vorgang.setAllgemeineMetadaten(createAllgemeineMetadaten(vorgangWithEingang));
		kontaktTypeCreator.create(vorgangWithEingang).ifPresent(vorgang.getKontakt()::add);
		return vorgang;
	}

	IdentifikationObjektType createIdentifikation() {
		var identifikation = new IdentifikationObjektType();
		identifikation.setID(UUID.randomUUID().toString());
		identifikation.setNummerImUebergeordnetenContainer(NUMMER_IM_UEBERGEORDNETEN_CONTAINER);
		return identifikation;
	}

	AllgemeineMetadatenType createAllgemeineMetadaten(VorgangWithEingang vorgang) {
		var allgemeineMetadaten = new AllgemeineMetadatenType();
		allgemeineMetadaten.setBetreff(vorgang.getName());
		allgemeineMetadaten.setKennzeichen(vorgang.getNummer());
		allgemeineMetadaten.setBemerkung(StringUtils.EMPTY);
		allgemeineMetadaten.setMedium(createMediumCode());
		return allgemeineMetadaten;
	}

	private MediumCodeType createMediumCode() {
		var mediumCode = new MediumCodeType();
		mediumCode.setCode(XdomeaMedienart.ELEKTRONISCHES_DOKUMENT.getCode());
		return mediumCode;
	}

}
