/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.archive;

import java.util.TimeZone;

import org.mapstruct.factory.Mappers;
import org.springframework.boot.SpringApplication;
import org.springframework.boot.autoconfigure.SpringBootApplication;
import org.springframework.boot.info.BuildProperties;
import org.springframework.boot.test.mock.mockito.MockBean;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.ComponentScan;
import org.springframework.security.authentication.AuthenticationTrustResolver;
import org.springframework.security.authentication.AuthenticationTrustResolverImpl;

import de.ozgcloud.apilib.client_attribute.grpc.OzgCloudClientAttributeMapper;
import de.ozgcloud.apilib.common.command.grpc.CommandMapper;
import de.ozgcloud.apilib.file.grpc.OzgCloudFileMapper;
import de.ozgcloud.apilib.user.UserProfileMapper;
import de.ozgcloud.apilib.vorgang.OzgCloudVorgangIdMapper;
import de.ozgcloud.apilib.vorgang.grpc.OzgCloudVorgangMapper;
import de.ozgcloud.vorgang.vorgang.VorgangServiceGrpc;
import de.ozgcloud.xta.client.XtaClient;

@SpringBootApplication
@ComponentScan({ "de.ozgcloud.*" })
public class ArchiveManagerTestApplication {

	@MockBean
	private OzgCloudVorgangMapper vorgangMapper;
	@MockBean
	private VorgangServiceGrpc.VorgangServiceBlockingStub vorgangServiceStub;
	@MockBean
	private OzgCloudVorgangIdMapper vorgangIdMapper;
	@MockBean
	private UserProfileMapper userProfileMapper;
	@MockBean
	private OzgCloudFileMapper fileMapper;
	@MockBean
	private BuildProperties properties;
	@MockBean
	private XtaClient xtaClient;
	@MockBean
	private OzgCloudClientAttributeMapper clientAttributeMapper;

	public static void main(String[] args) {
		TimeZone.setDefault(TimeZone.getTimeZone("UTC"));
		SpringApplication.run(ArchiveManagerTestApplication.class, args);
	}

	@Bean
	AuthenticationTrustResolver trustResolver() {
		return new AuthenticationTrustResolverImpl();
	}

	@Bean
	CommandMapper commandMapper() {
		return Mappers.getMapper(CommandMapper.class);
	}
}