/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.archive.common.binaryfile;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.Mockito.*;

import java.io.OutputStream;
import java.util.List;
import java.util.stream.Stream;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.Spy;

import de.ozgcloud.archive.file.OzgFile;
import de.ozgcloud.archive.file.OzgFileTestFactory;
import de.ozgcloud.common.binaryfile.FileId;

class BinaryFileServiceTest {

	@Spy
	@InjectMocks
	private BinaryFileService binaryFileService;

	@Mock
	private BinaryFileRemoteService binaryFileRemoteService;

	private final FileId fileId = OzgFileTestFactory.ID;

	private final OzgFile file = OzgFileTestFactory.create();

	@Nested
	class TestGetFiles {

		private final Stream<OzgFile> files = Stream.of(file);

		private final List<FileId> fileIds = List.of(fileId);

		@Test
		void shouldReturnFiles() {
			doReturn(files).when(binaryFileRemoteService).getFiles(fileIds);

			var result = binaryFileService.getFiles(fileIds);

			assertThat(result).isEqualTo(files);
		}

		@Test
		void shouldCallGetFiles() {
			binaryFileService.getFiles(fileIds);

			verify(binaryFileRemoteService).getFiles(fileIds);
		}
	}

	@Nested
	class TestGetFile {

		@Test
		void shouldReturnFiles() {
			doReturn(file).when(binaryFileRemoteService).getFile(fileId);

			var result = binaryFileService.getFile(fileId);

			assertThat(result).isEqualTo(file);
		}

		@Test
		void shouldCallGetFile() {
			binaryFileService.getFile(fileId);

			verify(binaryFileRemoteService).getFile(fileId);
		}

	}

	@Nested
	class TestWriteFileContent {

		@Mock
		private OutputStream outputStream;

		@Test
		void shouldWriteFileContent() {
			binaryFileService.writeFileContent(fileId, outputStream);

			verify(binaryFileRemoteService).writeFileContent(fileId, outputStream);
		}

	}

}