/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.archive.vorgang;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.ArgumentMatchers.*;
import static org.mockito.Mockito.*;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.Spy;

import de.xoev.xdomea.Antragsdaten;
import de.xoev.xdomea.AnwendungsspezifischeErweiterungXMLType;

public class AnwendungsspezifischeErweiterungXMLTypeCreatorTest {

	@Spy
	@InjectMocks
	private AnwendungsspezifischeErweiterungXMLTypeCreator creator;
	@Mock
	private FormDataMapper formDataMapper;

	@Nested
	class TestCreate {

		private final VorgangWithEingang vorgang = VorgangWithEingangTestFactory.create();
		private final Antragsdaten Antragsdaten = new Antragsdaten();

		@BeforeEach
		void init() {
			when(formDataMapper.toAntragsdaten(any())).thenReturn(Antragsdaten);
		}

		@Test
		void shouldCallFormDataMapper() {
			create();

			verify(formDataMapper).toAntragsdaten(vorgang);
		}

		@Test
		void shouldHaveAntragsdaten() {
			var anwendungsspezifischeErweiterung = create();

			assertThat(anwendungsspezifischeErweiterung.getAny()).hasSize(1).first().isEqualTo(Antragsdaten);
		}

		private AnwendungsspezifischeErweiterungXMLType create() {
			return creator.create(vorgang);
		}
	}
}
